@@ -24,7 +24,11 @@
 #include "gdict-client-context.h"
 #include "gdict-source.h"
 #include "gdict-source-loader.h"
+#include "gdict-source-chooser.h"
+#include "gdict-database-chooser.h"
 #include "gdict-defbox.h"
+#include "gdict-speller.h"
+#include "gdict-strategy-chooser.h"
 #include "gdict-utils.h"
 #include "gdict-enum-types.h"
 #include "gdict-version.h"
